@@ -2,6 +2,7 @@
 #include "norm.h"
 #include "snorm.h"
 #include "std.h"
+#include "sstd.h"
 #include "ast.h"
 #include "ald.h"
 #include "poi.h"
@@ -21,6 +22,7 @@ arma::mat IM_univ(arma::vec vTheta,std::string Dist){
   if(Dist == "norm") mIM = norm_IM(vTheta);
   if(Dist == "snorm") mIM = snorm_IM(vTheta);
   if(Dist == "std")  mIM = std_IM(vTheta);
+  if(Dist == "sstd")  mIM = sstd_IM(vTheta);
   if(Dist == "ast")  mIM = ast_IM(vTheta);
   if(Dist == "ast1") mIM = ast1_IM(vTheta);
   if(Dist == "ald") mIM = ald_IM(vTheta);
